[arvados] updated: 2.7.0-6271-gb56396475b

git repository hosting git at public.arvados.org
Fri Mar 29 15:20:47 UTC 2024


Summary of changes:
 services/workbench2/cypress/e2e/collection.cy.js               |  6 +++---
 services/workbench2/cypress/e2e/project.cy.js                  |  4 ++--
 services/workbench2/cypress/e2e/search.cy.js                   | 10 +++++-----
 services/workbench2/cypress/e2e/workflow.cy.js                 |  2 +-
 .../copy-to-clipboard-snackbar/copy-to-clipboard-snackbar.tsx  |  2 +-
 .../src/components/details-attribute/details-attribute.tsx     |  2 +-
 .../src/store/open-in-new-tab/open-in-new-tab.actions.ts       |  2 +-
 .../context-menu/actions/copy-to-clipboard-action.tsx          |  2 +-
 .../views-components/sharing-dialog/sharing-urls-component.tsx |  2 +-
 .../src/views-components/token-dialog/token-dialog.test.tsx    |  2 +-
 .../src/views-components/token-dialog/token-dialog.tsx         |  2 +-
 .../workbench2/src/views/process-panel/process-cmd-card.tsx    |  2 +-
 .../workbench2/src/views/process-panel/process-log-card.tsx    |  2 +-
 .../views/virtual-machine-panel/virtual-machine-user-panel.tsx |  2 +-
 14 files changed, 21 insertions(+), 21 deletions(-)

       via  b56396475bcae2a8a1356267120bc712538b198d (commit)
      from  9d762fe81ce5403a1a797a04e4e62c3d6d6f5b6f (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.


commit b56396475bcae2a8a1356267120bc712538b198d
Author: Lisa Knox <lisaknox83 at gmail.com>
Date:   Fri Mar 29 11:20:41 2024 -0400

    21448: expanded copy to oclipboard change Arvados-DCO-1.1-Signed-off-by: Lisa Knox <lisa.knox at curii.com>

diff --git a/services/workbench2/cypress/e2e/collection.cy.js b/services/workbench2/cypress/e2e/collection.cy.js
index 9c25f48f58..3a5cc27ec5 100644
--- a/services/workbench2/cypress/e2e/collection.cy.js
+++ b/services/workbench2/cypress/e2e/collection.cy.js
@@ -32,7 +32,7 @@ describe("Collection panel tests", function () {
         const msButtonTooltips = [
             'API Details',
             'Add to favorites',
-            'Copy to clipboard',
+            'Copy link to clipboard',
             'Edit collection',
             'Make a copy',
             'Move to',
@@ -351,7 +351,7 @@ describe("Collection panel tests", function () {
                             cy.get("[data-cy=context-menu]")
                                 .should("contain", "Download")
                                 .and("contain", "Open in new tab")
-                                .and("contain", "Copy to clipboard")
+                                .and("contain", "Copy link to clipboard")
                                 .and(`${isWritable ? "" : "not."}contain`, "Rename")
                                 .and(`${isWritable ? "" : "not."}contain`, "Remove");
                             cy.get("body").click(); // Collapse the menu
@@ -359,7 +359,7 @@ describe("Collection panel tests", function () {
                             cy.get("[data-cy=context-menu]")
                                 .should("not.contain", "Download")
                                 .and("contain", "Open in new tab")
-                                .and("contain", "Copy to clipboard")
+                                .and("contain", "Copy link to clipboard")
                                 .and(`${isWritable ? "" : "not."}contain`, "Rename")
                                 .and(`${isWritable ? "" : "not."}contain`, "Remove");
                             cy.get("body").click(); // Collapse the menu
diff --git a/services/workbench2/cypress/e2e/project.cy.js b/services/workbench2/cypress/e2e/project.cy.js
index 4b38fe6d92..912e765a88 100644
--- a/services/workbench2/cypress/e2e/project.cy.js
+++ b/services/workbench2/cypress/e2e/project.cy.js
@@ -221,7 +221,7 @@ describe("Project tests", function () {
         const msButtonTooltips = [
             'API Details',
             'Add to favorites',
-            'Copy to clipboard',
+            'Copy link to clipboard',
             'Edit project',
             'Freeze project',
             'Move to',
@@ -636,7 +636,7 @@ describe("Project tests", function () {
         cy.get("[data-cy=side-panel-tree]").contains("Projects").click();
         cy.waitForDom();
         cy.get("[data-cy=project-panel]").contains(projectName).should("be.visible").rightclick();
-        cy.get("[data-cy=context-menu]").contains("Copy to clipboard").click();
+        cy.get("[data-cy=context-menu]").contains("Copy link to clipboard").click();
         cy.window().then(win =>
             win.navigator.clipboard.readText().then(text => {
                 expect(text).to.match(/https\:\/\/127\.0\.0\.1\:[0-9]+\/projects\/[a-z0-9]{5}-[a-z0-9]{5}-[a-z0-9]{15}/);
diff --git a/services/workbench2/cypress/e2e/workflow.cy.js b/services/workbench2/cypress/e2e/workflow.cy.js
index c6c49ee343..f0c91a7722 100644
--- a/services/workbench2/cypress/e2e/workflow.cy.js
+++ b/services/workbench2/cypress/e2e/workflow.cy.js
@@ -270,7 +270,7 @@ describe('Registered workflow panel tests', function() {
 
         const msButtonTooltips = [
             'API Details',
-            'Copy to clipboard',
+            'Copy link to clipboard',
             'Delete Workflow',
             'Open in new tab',
             'Run Workflow',
diff --git a/services/workbench2/src/components/copy-to-clipboard-snackbar/copy-to-clipboard-snackbar.tsx b/services/workbench2/src/components/copy-to-clipboard-snackbar/copy-to-clipboard-snackbar.tsx
index 3ef483dfe0..13e6531766 100644
--- a/services/workbench2/src/components/copy-to-clipboard-snackbar/copy-to-clipboard-snackbar.tsx
+++ b/services/workbench2/src/components/copy-to-clipboard-snackbar/copy-to-clipboard-snackbar.tsx
@@ -48,7 +48,7 @@ export const CopyToClipboardSnackbar = connect()(
             render() {
                 const { children, value, classes } = this.props;
                 return (
-                    <Tooltip title='Copy to clipboard' onClick={(ev) => ev.stopPropagation()}>
+                    <Tooltip title='Copy link to clipboard' onClick={(ev) => ev.stopPropagation()}>
                         <span className={classes.copyIcon}>
                             <CopyToClipboard text={value} onCopy={this.onCopy}>
                                 {children || <CopyIcon />}
diff --git a/services/workbench2/src/components/details-attribute/details-attribute.tsx b/services/workbench2/src/components/details-attribute/details-attribute.tsx
index 5130db56d1..1f1996424c 100644
--- a/services/workbench2/src/components/details-attribute/details-attribute.tsx
+++ b/services/workbench2/src/components/details-attribute/details-attribute.tsx
@@ -124,7 +124,7 @@ export const DetailsAttributeComponent = withStyles(styles)(
                 className={classnames([props.classes.value, props.classValue, { [props.classes.lowercaseValue]: props.lowercaseValue }])}>
                 {props.value}
                 {props.children}
-                {(props.linkToUuid || props.copyValue) && props.onCopy && <Tooltip title="Copy to clipboard">
+                {(props.linkToUuid || props.copyValue) && props.onCopy && <Tooltip title="Copy link to clipboard">
                     <span className={props.classes.copyIcon}>
                         <CopyToClipboard text={props.linkToUuid || props.copyValue || ""} onCopy={() => props.onCopy!("Copied")}>
                             <CopyIcon />
diff --git a/services/workbench2/src/store/open-in-new-tab/open-in-new-tab.actions.ts b/services/workbench2/src/store/open-in-new-tab/open-in-new-tab.actions.ts
index 28da3cf95a..2d1ab2e40d 100644
--- a/services/workbench2/src/store/open-in-new-tab/open-in-new-tab.actions.ts
+++ b/services/workbench2/src/store/open-in-new-tab/open-in-new-tab.actions.ts
@@ -19,7 +19,7 @@ export const openInNewTabAction = (resource: any) => (dispatch: Dispatch, getSta
 };
 
 export const copyToClipboardAction = (resources: Array<any>) => (dispatch: Dispatch, getState: () => RootState) => {
-    // Copy to clipboard omits token to avoid accidental sharing
+    // Copy link to clipboard omits token to avoid accidental sharing
 
     let url = getNavUrl(resources[0].uuid, getState().auth, false);
     let wasCopied;
diff --git a/services/workbench2/src/views-components/context-menu/actions/copy-to-clipboard-action.tsx b/services/workbench2/src/views-components/context-menu/actions/copy-to-clipboard-action.tsx
index 50ed20fd7f..7b6501dc2e 100644
--- a/services/workbench2/src/views-components/context-menu/actions/copy-to-clipboard-action.tsx
+++ b/services/workbench2/src/views-components/context-menu/actions/copy-to-clipboard-action.tsx
@@ -26,7 +26,7 @@ export const CopyToClipboardAction = (props: { href?: any, download?: any, onCli
                 <Link />
             </ListItemIcon>
             <ListItemText>
-                Copy to clipboard
+                Copy link to clipboard
             </ListItemText>
         </ListItem>
         : null;
diff --git a/services/workbench2/src/views-components/sharing-dialog/sharing-urls-component.tsx b/services/workbench2/src/views-components/sharing-dialog/sharing-urls-component.tsx
index c17fadd5f0..7bb05fa0dc 100644
--- a/services/workbench2/src/views-components/sharing-dialog/sharing-urls-component.tsx
+++ b/services/workbench2/src/views-components/sharing-dialog/sharing-urls-component.tsx
@@ -78,7 +78,7 @@ export const SharingURLsComponent = withStyles(styles)((props: SharingURLsCompon
                     </Grid>
                     <Grid item xs />
                     <Grid item>
-                        <span className={props.classes.sharingUrlButton}><Tooltip title='Copy to clipboard'>
+                        <span className={props.classes.sharingUrlButton}><Tooltip title='Copy link to clipboard'>
                             <CopyToClipboard text={url} onCopy={() => props.onCopy('Sharing URL copied')}>
                                 <CopyIcon />
                             </CopyToClipboard>
diff --git a/services/workbench2/src/views-components/token-dialog/token-dialog.test.tsx b/services/workbench2/src/views-components/token-dialog/token-dialog.test.tsx
index 400bb1e687..ec68beab9d 100644
--- a/services/workbench2/src/views-components/token-dialog/token-dialog.test.tsx
+++ b/services/workbench2/src/views-components/token-dialog/token-dialog.test.tsx
@@ -88,7 +88,7 @@ describe('<CurrentTokenDialog />', () => {
     });
   });
 
-  describe('copy to clipboard button', () => {
+  describe('Copy link to clipboard button', () => {
     beforeEach(() => {
       wrapper = mount(
         <Provider store={store}>
diff --git a/services/workbench2/src/views-components/token-dialog/token-dialog.tsx b/services/workbench2/src/views-components/token-dialog/token-dialog.tsx
index e6f3ed582c..ad1093d7e5 100644
--- a/services/workbench2/src/views-components/token-dialog/token-dialog.tsx
+++ b/services/workbench2/src/views-components/token-dialog/token-dialog.tsx
@@ -140,7 +140,7 @@ unset ARVADOS_API_HOST_INSECURE`
                         variant="contained"
                         className={classes.actionButton}
                     >
-                        COPY TO CLIPBOARD
+                        Copy link to clipBOARD
                     </Button>
                 </CopyToClipboard>
                 <Typography>
diff --git a/services/workbench2/src/views/process-panel/process-cmd-card.tsx b/services/workbench2/src/views/process-panel/process-cmd-card.tsx
index d8368449cb..478b0bc56f 100644
--- a/services/workbench2/src/views/process-panel/process-cmd-card.tsx
+++ b/services/workbench2/src/views/process-panel/process-cmd-card.tsx
@@ -100,7 +100,7 @@ export const ProcessCmdCard = withStyles(styles)(
           action={
             <Grid container direction="row" alignItems="center">
               <Grid item>
-                <Tooltip title="Copy to clipboard" disableFocusListener>
+                <Tooltip title="Copy link to clipboard" disableFocusListener>
                   <IconButton>
                     <CopyToClipboard
                       text={command.join(" ")}
diff --git a/services/workbench2/src/views/process-panel/process-log-card.tsx b/services/workbench2/src/views/process-panel/process-log-card.tsx
index 4fd8f2343d..b141abf24c 100644
--- a/services/workbench2/src/views/process-panel/process-log-card.tsx
+++ b/services/workbench2/src/views/process-panel/process-log-card.tsx
@@ -131,7 +131,7 @@ export const ProcessLogsCard = withStyles(styles)(
                             </Tooltip>
                         </Grid>
                         <Grid item>
-                            <Tooltip title="Copy to clipboard" disableFocusListener>
+                            <Tooltip title="Copy link to clipboard" disableFocusListener>
                                 <IconButton>
                                     <CopyToClipboard text={lines.join()} onCopy={() => onCopy("Log copied to clipboard")}>
                                         <CopyIcon />
diff --git a/services/workbench2/src/views/virtual-machine-panel/virtual-machine-user-panel.tsx b/services/workbench2/src/views/virtual-machine-panel/virtual-machine-user-panel.tsx
index 36d432f95a..ae365ce0a9 100644
--- a/services/workbench2/src/views/virtual-machine-panel/virtual-machine-user-panel.tsx
+++ b/services/workbench2/src/views/virtual-machine-panel/virtual-machine-user-panel.tsx
@@ -238,7 +238,7 @@ const virtualMachinesTable = (props: VirtualMachineProps) =>
                             </TableCell>
                             <TableCell>
                                 {command}
-                                <Tooltip title="Copy to clipboard">
+                                <Tooltip title="Copy link to clipboard">
                                     <span className={props.classes.copyIcon}>
                                         <CopyToClipboard text={command || ""} onCopy={() => props.onCopy!("Copied")}>
                                             <CopyIcon />

-----------------------------------------------------------------------


hooks/post-receive
diff --git a/services/workbench2/cypress/e2e/search.cy.js b/services/workbench2/cypress/e2e/search.cy.js
index ba9077ac20..094a3f618c 100644
--- a/services/workbench2/cypress/e2e/search.cy.js
+++ b/services/workbench2/cypress/e2e/search.cy.js
@@ -271,17 +271,17 @@ describe("Search tests", function () {
                 cy.stub(win, "open").as("Open");
             });
 
             // Check copy to clipboard
             cy.get("[data-cy=search-results]").contains(colName).rightclick();
             cy.get("[data-cy=context-menu]").within(ctx => {
                 // Check that there are 4 items in the menu
                 cy.get(ctx).children().should("have.length", 4);
                 cy.contains("API Details");
-                cy.contains("Copy to clipboard");
+                cy.contains("Copy link to clipboard");
                 cy.contains("Open in new tab");
                 cy.contains("View details");
 
-                cy.contains("Copy to clipboard").click();
+                cy.contains("Copy link to clipboard").click();
                 cy.waitForDom();
                 cy.window().then(win =>
                     win.navigator.clipboard.readText().then(text => {
@@ -298,10 +298,10 @@ describe("Search tests", function () {
                 cy.get("@Open").should("have.been.calledOnceWith", `${window.location.origin}/collections/${testCollection.uuid}`);
             });
 
             // Check federated result copy to clipboard
             cy.get("[data-cy=search-results]").contains(federatedColName).rightclick();
             cy.get("[data-cy=context-menu]").within(() => {
-                cy.contains("Copy to clipboard").click();
+                cy.contains("Copy link to clipboard").click();
                 cy.waitForDom();
                 cy.window().then(win =>
                     win.navigator.clipboard.readText().then(text => {
@@ -271,17 +271,17 @@ describe("Search tests", function () {
             });
 
-            // Check copy to clipboard
+            // Check Copy link to clipboard
             cy.get("[data-cy=search-results]").contains(colName).rightclick();
             cy.get("[data-cy=context-menu]").within(ctx => {
@@ -298,10 +298,10 @@ describe("Search tests", function () {
             });
 
-            // Check federated result copy to clipboard
+            // Check federated result Copy link to clipboard
             cy.get("[data-cy=search-results]").contains(federatedColName).rightclick();
             cy.get("[data-cy=context-menu]").within(() => {
-- 




More information about the arvados-commits mailing list